SequentialGroupQuota — alfred3_interact

Skip to main content
`Ctrl`+`K`

# SequentialGroupQuota

class alfred3_interact.quota.SequentialGroupQuota(nslots: int, exp, name: str = 'group_quota', **kwargs)

  Bases: `ParallelGroupQuota`

  Manages quota for sequential groups.

  Parameters

    **kwargs –

    Inherited keyword arguments

    abort_page (alfred3.Page) | You can reference a custom page to be displayed to new participants, if the quota is full.
    exp (alfred3.ExperimentSession) | Experiment session.
    inclusive (bool) | If False (default), the quota will only assign a slot, if there are no pending sessions for that slot. It will not assign a slot, if a session in that slot is finished, or if there is an ongoing session in that slot that has not yet timed out. You will end up with exactly as many participants, as specified in nslots. If True, the quota will assign a slot, if there is no finished session in that slot. That means, there may be two ongoing sessions for the same slot, and both might end up to finish. While inclusive=*False* may lead to participants being turned away before the experiment is really complete, inclusive=True may lead to more data being collected than necessary. Defaults to False.
    name (str) | An identifier for the quota. If you give this a custom value, you can use multiple quotas in the same experiment. Defaults to quota.
    nslots (int) | Maximum number of slots.
    respect_version (bool) |

  Methods

  `count` | Counts the experiment session associated with the quota.
  `next` | Returns the next open slot.

  Attributes

  `DATA_TYPE` |
  `allfinished` | Indicates, whether all slots in the quota are finished.
  `full` | True, if all slots are taken and no group currently takes members.
  `group_type` |
  `nfinished` | Number of finished slots.
  `nopen` | Number of open slots.
  `npending` | Number of slots in which a session is still ongoing.